@@ -3,10 +3,10 @@ use Moose;
 
 has 'instance_id'       => ( is => 'ro', isa => 'Str', required => 1 );
 has 'image_id'          => ( is => 'ro', isa => 'Str', required => 1 );
-has 'private_dns_name'  => ( is => 'ro', isa => 'Str|Undef' );
-has 'dns_name'          => ( is => 'ro', isa => 'Str|Undef' );
-has 'reason'            => ( is => 'ro', isa => 'Str|Undef' );
-has 'key_name'          => ( is => 'ro', isa => 'Str' );
+has 'private_dns_name'  => ( is => 'ro', isa => 'Str|Undef', default => '' );
+has 'dns_name'          => ( is => 'ro', isa => 'Str|Undef', default => '' );
+has 'reason'            => ( is => 'ro', isa => 'Str|Undef', default => '' );
+has 'key_name'          => ( is => 'ro', isa => 'Str|Undef', default => '' );
 has 'ami_launch_index'  => ( is => 'ro', isa => 'Str' );
 has 'instance_type'     => ( is => 'ro', isa => 'Str', required => 1 );
 has 'launch_time'       => ( is => 'ro', isa => 'Str', required => 1 );
